==> ideaIC-141.3057.6-sources.jar: com/intellij/dvcs/ui/VcsLogSingleCommitAction.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.dvcs.ui;

import com.intellij.dvcs.repo.Repository;
import com.intellij.openapi.project.Project;
import com.intellij.util.containers.MultiMap;
import com.intellij.vcs.log.VcsFullCommitDetails;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;
import java.util.Map;

public abstract class VcsLogSingleCommitAction<Repo extends Repository> extends VcsLogAction<Repo> {

  @Override
  protected boolean isEnabled(@NotNull MultiMap<Repo, VcsFullCommitDetails> grouped) {
    return grouped.size() == 1;
  }

  @Override
  protected void actionPerformed(@NotNull Project project, @NotNull MultiMap<Repo, VcsFullCommitDetails> grouped) {
    assert grouped.size() == 1;
    Map.Entry<Repo, Collection<VcsFullCommitDetails>> entry = grouped.entrySet().iterator().next();
    Repo repository = entry.getKey();
    Collection<VcsFullCommitDetails> commits = entry.getValue();
    assert commits.size() == 1;
    actionPerformed(repository, commits.iterator().next());
  }

  protected abstract void actionPerformed(@NotNull Repo repository, @NotNull VcsFullCommitDetails commit);

}

==> ideaIC-143.1453.5-sources.jar: com/intellij/dvcs/ui/VcsLogSingleCommitAction.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.dvcs.ui;

import com.intellij.dvcs.repo.Repository;
import com.intellij.openapi.project.Project;
import com.intellij.util.containers.MultiMap;
import com.intellij.vcs.log.VcsFullCommitDetails;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;
import java.util.Map;

public abstract class VcsLogSingleCommitAction<Repo extends Repository> extends VcsLogAction<Repo> {

  @Override
  protected boolean isEnabled(@NotNull MultiMap<Repo, VcsFullCommitDetails> grouped) {
    return grouped.values().size() == 1;
  }

  @Override
  protected void actionPerformed(@NotNull Project project, @NotNull MultiMap<Repo, VcsFullCommitDetails> grouped) {
    assert grouped.size() == 1;
    Map.Entry<Repo, Collection<VcsFullCommitDetails>> entry = grouped.entrySet().iterator().next();
    Repo repository = entry.getKey();
    Collection<VcsFullCommitDetails> commits = entry.getValue();
    assert commits.size() == 1;
    actionPerformed(repository, commits.iterator().next());
  }

  protected abstract void actionPerformed(@NotNull Repo repository, @NotNull VcsFullCommitDetails commit);

}
